@@ -1,3 +1,3 @@
-from .utils import TradeSide
+from .utils import TradeSide, strategy
 from .brokers import TradingClient
 from .trading_sys import Trader, ExampleStrategies
